Documentation
¶
Index ¶
- func GenerateCertificateAuthorityConfiguration(p v1beta1.CertificateAuthorityConfiguration) *types.CertificateAuthorityConfiguration
- func GenerateCertificateAuthorityExternalStatus(certificateAuthority types.CertificateAuthority) v1beta1.CertificateAuthorityExternalStatus
- func GenerateCreateCertificateAuthorityInput(p *v1beta1.CertificateAuthorityParameters) *acmpca.CreateCertificateAuthorityInput
- func GenerateRevocationConfiguration(p *v1beta1.RevocationConfiguration) *types.RevocationConfiguration
- func IsCertificateAuthorityUpToDate(p *v1beta1.CertificateAuthority, cd types.CertificateAuthority, ...) bool
- func IsErrorNotFound(err error) bool
- func LateInitializeCertificateAuthority(in *v1beta1.CertificateAuthorityParameters, ...)
- type CAPermissionClient
- type Client
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateCertificateAuthorityConfiguration ¶
func GenerateCertificateAuthorityConfiguration(p v1beta1.CertificateAuthorityConfiguration) *types.CertificateAuthorityConfiguration
GenerateCertificateAuthorityConfiguration from CertificateAuthorityConfiguration
func GenerateCertificateAuthorityExternalStatus ¶
func GenerateCertificateAuthorityExternalStatus(certificateAuthority types.CertificateAuthority) v1beta1.CertificateAuthorityExternalStatus
GenerateCertificateAuthorityExternalStatus is used to produce CertificateAuthorityExternalStatus from acmpca.certificateAuthorityStatus and v1alpha1.CertificateAuthority
func GenerateCreateCertificateAuthorityInput ¶
func GenerateCreateCertificateAuthorityInput(p *v1beta1.CertificateAuthorityParameters) *acmpca.CreateCertificateAuthorityInput
GenerateCreateCertificateAuthorityInput from certificateAuthorityParameters
func GenerateRevocationConfiguration ¶
func GenerateRevocationConfiguration(p *v1beta1.RevocationConfiguration) *types.RevocationConfiguration
GenerateRevocationConfiguration from RevocationConfiguration
func IsCertificateAuthorityUpToDate ¶
func IsCertificateAuthorityUpToDate(p *v1beta1.CertificateAuthority, cd types.CertificateAuthority, tags []types.Tag) bool
IsCertificateAuthorityUpToDate checks whether there is a change in any of the modifiable fields.
func IsErrorNotFound ¶
IsErrorNotFound returns true if the error code indicates that the item was not found
func LateInitializeCertificateAuthority ¶
func LateInitializeCertificateAuthority(in *v1beta1.CertificateAuthorityParameters, certificateAuthority *types.CertificateAuthority)
LateInitializeCertificateAuthority fills the empty fields in *v1beta1.CertificateAuthorityParameters with the values seen in acmpca.CertificateAuthority.
Types ¶
type CAPermissionClient ¶
type CAPermissionClient interface {
CreatePermission(context.Context, *acmpca.CreatePermissionInput, ...func(*acmpca.Options)) (*acmpca.CreatePermissionOutput, error)
DeletePermission(context.Context, *acmpca.DeletePermissionInput, ...func(*acmpca.Options)) (*acmpca.DeletePermissionOutput, error)
ListPermissions(context.Context, *acmpca.ListPermissionsInput, ...func(*acmpca.Options)) (*acmpca.ListPermissionsOutput, error)
}
CAPermissionClient defines the CertificateManager operations
func NewCAPermissionClient ¶
func NewCAPermissionClient(conf *aws.Config) CAPermissionClient
NewCAPermissionClient returns a new client using AWS credentials as JSON encoded data.
type Client ¶
type Client interface {
CreateCertificateAuthority(context.Context, *acmpca.CreateCertificateAuthorityInput, ...func(*acmpca.Options)) (*acmpca.CreateCertificateAuthorityOutput, error)
DeleteCertificateAuthority(context.Context, *acmpca.DeleteCertificateAuthorityInput, ...func(*acmpca.Options)) (*acmpca.DeleteCertificateAuthorityOutput, error)
UpdateCertificateAuthority(context.Context, *acmpca.UpdateCertificateAuthorityInput, ...func(*acmpca.Options)) (*acmpca.UpdateCertificateAuthorityOutput, error)
DescribeCertificateAuthority(context.Context, *acmpca.DescribeCertificateAuthorityInput, ...func(*acmpca.Options)) (*acmpca.DescribeCertificateAuthorityOutput, error)
ListTags(context.Context, *acmpca.ListTagsInput, ...func(*acmpca.Options)) (*acmpca.ListTagsOutput, error)
UntagCertificateAuthority(context.Context, *acmpca.UntagCertificateAuthorityInput, ...func(*acmpca.Options)) (*acmpca.UntagCertificateAuthorityOutput, error)
TagCertificateAuthority(context.Context, *acmpca.TagCertificateAuthorityInput, ...func(*acmpca.Options)) (*acmpca.TagCertificateAuthorityOutput, error)
}
Client defines the CertificateManager operations